==> scorchful-0.15.5%2B1.21.4-sources.jar: com/github/thedeathlycow/scorchful/item/enchantment/EnchantmentModifiers.java <==
package com.github.thedeathlycow.scorchful.item.enchantment;

import com.github.thedeathlycow.scorchful.Scorchful;
import com.github.thedeathlycow.scorchful.config.CombatConfig;
import com.github.thedeathlycow.thermoo.api.ThermooAttributes;
import com.github.thedeathlycow.thermoo.api.predicate.SoakedLootCondition;
import net.fabricmc.fabric.api.item.v1.EnchantmentEvents;
import net.fabricmc.fabric.api.item.v1.EnchantmentSource;
import net.minecraft.class_1322;
import net.minecraft.class_1887;
import net.minecraft.class_1893;
import net.minecraft.class_2096;
import net.minecraft.class_5321;
import net.minecraft.class_9701;
import net.minecraft.class_9704;
import net.minecraft.class_9711;
import net.minecraft.class_9720;

public class EnchantmentModifiers {

    public static void initialize() {
        EnchantmentEvents.MODIFY.register(EnchantmentModifiers::modifyFireProtection);
        EnchantmentEvents.MODIFY.register(EnchantmentModifiers::modifyImpaling);
    }

    private static void modifyImpaling(class_5321<class_1887> key, class_1887.class_9700 builder, EnchantmentSource source) {
        if (!source.isBuiltin() || key != class_1893.field_9106) {
            return;
        }

        CombatConfig config = Scorchful.getConfig().combatConfig;

        builder.method_60067(
                class_9701.field_51661,
                new class_9711(class_9704.method_60194(config.getImpalingDamagePerLevel())),
                SoakedLootCondition.builder(class_2096.class_2100.method_9053(1))
                // TODO: registry lookup doesnt work, throws: java.lang.IllegalStateException: Missing tag TagKey[minecraft:entity_type / minecraft:sensitive_to_impaling]
//                AllOfLootCondition.builder(
//                        () -> new SoakedLootCondition(
//                                ,
//                                NumberRange.DoubleRange.ANY
//                        ),
//                        InvertedLootCondition.builder(
//                                EntityPropertiesLootCondition.builder(
//                                        LootContext.EntityTarget.THIS,
//                                        EntityPredicate.Builder.create()
//                                                .type(EntityTypePredicate.create(
//                                                        Registries.ENTITY_TYPE,
//                                                        EntityTypeTags.SENSITIVE_TO_IMPALING
//                                                ))
//                                )
//                        )
//                )
        );
    }

    private static void modifyFireProtection(class_5321<class_1887> key, class_1887.class_9700 builder, EnchantmentSource source) {
        if (!source.isBuiltin() || key != class_1893.field_9095) {
            return;
        }

        double valuePerLevel = Scorchful.getConfig().combatConfig.getFireProtectionHeatResistancePerLevel();
        builder.method_60065(
                class_9701.field_51668,
                new class_9720(
                        Scorchful.id("enchantment.fire_protection.heat_resistance"),
                        ThermooAttributes.HEAT_RESISTANCE,
                        class_9704.method_60194((float) valuePerLevel),
                        class_1322.class_1323.field_6328
                )
        );
    }

    private EnchantmentModifiers() {

    }
}

==> scorchful-0.15.8%2B1.21.1-sources.jar: com/github/thedeathlycow/scorchful/item/enchantment/EnchantmentModifiers.java <==
package com.github.thedeathlycow.scorchful.item.enchantment;

import com.github.thedeathlycow.scorchful.Scorchful;
import com.github.thedeathlycow.scorchful.config.CombatConfig;
import com.github.thedeathlycow.thermoo.api.ThermooAttributes;
import com.github.thedeathlycow.thermoo.api.predicate.SoakedLootCondition;
import net.fabricmc.fabric.api.item.v1.EnchantmentEvents;
import net.fabricmc.fabric.api.item.v1.EnchantmentSource;
import net.minecraft.class_1322;
import net.minecraft.class_1887;
import net.minecraft.class_1893;
import net.minecraft.class_2048;
import net.minecraft.class_2050;
import net.minecraft.class_207;
import net.minecraft.class_2096;
import net.minecraft.class_215;
import net.minecraft.class_3483;
import net.minecraft.class_47;
import net.minecraft.class_5321;
import net.minecraft.class_8548;
import net.minecraft.class_9701;
import net.minecraft.class_9704;
import net.minecraft.class_9711;
import net.minecraft.class_9720;

public class EnchantmentModifiers {

    public static void initialize() {
        EnchantmentEvents.MODIFY.register(EnchantmentModifiers::modifyFireProtection);
        EnchantmentEvents.MODIFY.register(EnchantmentModifiers::modifyImpaling);
    }

    private static void modifyImpaling(class_5321<class_1887> key, class_1887.class_9700 builder, EnchantmentSource source) {
        if (!source.isBuiltin() || key != class_1893.field_9106) {
            return;
        }

        CombatConfig config = Scorchful.getConfig().combatConfig;
        builder.method_60067(
                class_9701.field_51661,
                new class_9711(class_9704.method_60194(config.getImpalingDamagePerLevel())),
                class_8548.method_51723(
                        () -> new SoakedLootCondition(
                                class_2096.class_2100.method_9053(1),
                                class_2096.class_2099.field_9705
                        ),
                        class_207.method_889(
                                class_215.method_917(
                                        class_47.class_50.field_935,
                                        class_2048.class_2049.method_8916()
                                                .method_8917(class_2050.method_8926(class_3483.field_48284))
                                )
                        )
                )
        );
    }

    private static void modifyFireProtection(class_5321<class_1887> key, class_1887.class_9700 builder, EnchantmentSource source) {
        if (!source.isBuiltin() || key != class_1893.field_9095) {
            return;
        }

        double valuePerLevel = Scorchful.getConfig().combatConfig.getFireProtectionHeatResistancePerLevel();
        builder.method_60065(
                class_9701.field_51668,
                new class_9720(
                        Scorchful.id("enchantment.fire_protection.heat_resistance"),
                        ThermooAttributes.HEAT_RESISTANCE,
                        class_9704.method_60194((float) valuePerLevel),
                        class_1322.class_1323.field_6328
                )
        );
    }

    private EnchantmentModifiers() {

    }
}
